class ValidatorBase:
    def __init__(self):
        pass


class ValidateCSV(ValidatorBase):
    def __init__(self):
        super().__init__()


class ValidateJSON(ValidatorBase):
    def __init__(self):
        super().__init__()


class ValidateINI(ValidatorBase):
    def __init__(self):
        super().__init__()


class ValidateYAML(ValidatorBase):
    def __init__(self):
        super().__init__()
